# Generated by Django 2.1.5 on 2019-02-09 22:40

from django.db import migrations, models
import lactolyse.models


class Migration(migrations.Migration):

    dependencies = [('lactolyse', '0004_conconi_test')]

    operations = [
        migrations.AlterField(
            model_name='conconitestanalyses',
            name='report',
            field=models.FileField(
                upload_to=lactolyse.models.generate_conconi_test_name
            ),
        )
    ]
